@@ -152,7 +152,6 @@ yhat.predict <- function(model_name, version, data) {
 #' model.predict <- function(df) {
 #'  data.frame("prediction"=predict(fit, df, type="response"))
 #' } 
-#' yhat.login("rtest", "abcd1234")
 #' yhat.deploy("irisModel")
 yhat.deploy <- function(model_name) {
   AUTH <- get("yhat.config")
@@ -201,42 +200,72 @@ model_require <- function() {
   close(con)
 }
 
-# 
-# ####sample user code####
-# #yhat.login("greg", "fCVZiLJhS95cnxOrsp5e2VSkk0GfypZqeRCntTD1nHA")
-# rsp <- yhat.deploy("gregsModel")
-# yhat.show_models()
-# 
-# yhat.predict_raw("MySMSClassifier", 12, "sex boner this shit")
-# yhat.predict("MySMSClassifier", 12, "sex boner this shit")
-# yhat.predict("MySMSClassifier", 12, "hello")
-# library(randomForest)
-# x <- 1:100
-# xsq <- x^2
-# y <- sin(x) + runif(length(x), -.3, .3)
-# data <- data.frame(x=x, xsq=xsq, y=y)
-# (fit <- randomForest(y ~ x + xsq, data=data))
-# (fit <- lm(y ~ x + xsq, data=data))
-# 
-# model.transform <- function(df) {
-#   df$xsq <- df$x^2
-#   df
-# }
-# 
-# model.predict <- function(x) {
-#   p <- predict(fit, newdata=x)
-#   data.frame("prediction"=p)
-# }
-# 
-# model.require <- function() {
-#   library("randomForest")
-# }
-# 
-# 
-# model.predict(model.transform(data.frame(x=2)))
-# 
-# yhat.deploy("gregsModel")
-# rsp <- yhat.predict_raw("gregsModel", 16, data.frame(x=c(-10, 5)))
-# yhat.predict("gregsModel", 16, data.frame(x=c(2, 5)))
-# 
-# 
+#' Documents a column from a given data.frame
+#' 
+#' Generates documentation for a column.
+#' @param df the data.farme frame you're documenting
+#' @param col the column as a string that you're documenting
+documentColumn <- function(df, col) {
+  doc <- list()
+  doc[["name"]] <- col
+  doc[["dtype"]] <- ifelse(is.numeric(df[,col]), "number",
+                           ifelse(is.factor(df[,col]), "factor",
+                                  "something else"))
+  if (doc[["dtype"]]=="number") {
+    step <- abs(max(df[,col], na.rm=T) - min(df[,col], na.rm=T) )/ 10 + 0.01
+    doc[["step"]] <- 10^round(log10(step) - log10(5.5) + 0.5)
+    doc[["placeholder"]] <- median(df[,col], na.rm=T)
+  } else if(doc[["dtype"]]=="factor") {
+    factorLevels <- list()
+    levs <- sort(levels(df[,col]))
+    doc[["levels"]] <- lapply(levs, I)
+  } else {
+    doc[["placeholder"]] <- "your text here"
+  }
+  doc
+}
+
+#' Private method for generating documentation for a data frame
+#' 
+#' Documents a data frame using the \link{documentColumn} function.
+#' @param data the data.frame you're documenting
+documentData <- function(data) {
+  docs <- list()
+  for(col in names(data)) {
+    docs[[length(docs)+1]] <- documentColumn(data, col)
+  }
+  docs
+}
+
+#' Document a model using Yhat
+#' 
+#' Takes a specific model along with data that is required to execute a prediction
+#' and generates a webapp/documentation.
+#' 
+#' @param model name of your model
+#' @param version version of your model
+#' @param df example data for your model
+#' @keywords document
+#' @export
+yhat.document <- function(model, version, df) {
+  docs <- documentData(df)
+  
+  AUTH <- get("yhat.config")
+  if (length(AUTH)==0) {
+    stop("You must login. execute yhat.login(username, apikey).")
+  }
+  query <- AUTH
+  query["model"] <- model
+  query["version"] <- version
+  query <- paste(names(query), query, collapse="&", sep="=")
+  url <- paste(YHAT_URL, "document", "?", query, sep="")
+  
+  
+  rsp <- httr::POST(url, httr::add_headers("Content-Type"="application/json"),
+             body = rjson::toJSON(list(
+               docs = docs)
+             ))
+  httr::content(rsp)
+}
+
+
